@@ -10,7 +10,7 @@ use File::Spec ();
 use File::Temp ();
 use POSIX ':sys_wait_h';
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 our $VERBOSE = 0;
 our $ALLOW_DEV_VERSION = 0;
 our $FORK = 0;
@@ -237,6 +237,8 @@ sub _parse_version {
                 utf8::encode($v);
                 # undefine empty $v as if read from the tmpfile
                 $v = undef if defined $v && !length $v;
+                $comp->erase;
+                $self->_restore_overloaded_stuff;
             }
         }
     }
@@ -245,6 +247,28 @@ sub _parse_version {
     return $self->_normalize_version($v);
 }
 
+sub _restore_overloaded_stuff {
+    my $self = shift;
+    return unless $] >= 5.009000;
+
+    no strict 'refs';
+    no warnings 'redefine';
+
+    if (version->isa('version::vxs')) {
+        *{'version::(""'} = \&version::vxs::stringify;
+        *{'version::(0+'} = \&version::vxs::numify;
+        *{'version::(cmp'} = \&version::vxs::VCMP;
+        *{'version::(<=>'} = \&version::vxs::VCMP;
+        *{'version::(bool'} = \&version::vxs::boolean;
+    } else {
+        *{'version::(""'} = \&version::vpp::stringify;
+        *{'version::(0+'} = \&version::vpp::numify;
+        *{'version::(cmp'} = \&version::vpp::vcmp;
+        *{'version::(<=>'} = \&version::vpp::vcmp;
+        *{'version::(bool'} = \&version::vpp::vbool;
+    }
+}
+
 # from PAUSE::pmfile;
 sub _packages_per_pmfile {
     my $self = shift;
